@@ -104,7 +104,7 @@ HepSymMatrix::~HepSymMatrix() {
 }
 
 HepSymMatrix::HepSymMatrix(const HepSymMatrix &m1)
-   : m(m1.size_), nrow(m1.nrow), size_(m1.size_)
+   : HepGenMatrix(m1), m(m1.size_), nrow(m1.nrow), size_(m1.size_)
 {
    m = m1.m;
 }
